{% extends "base-site.html" %}

{% block title %} {{ _('Credits') }} {% endblock %}

<!-- Specific Page CSS goes HERE  -->
{% block stylesheets %}{% endblock stylesheets %}

{% block content %}

<div class="row">
    <div class="col-md-12">
        <div class="card card-profile">
            <div class="card-body">
                <h6 class="card-category text-gray">Dashboard Credits</h6>
                <h4 class="card-title">
                    {% if redirect %}
                    {{ _('This instance of Red Discord Bot is owned by {owner}.').format(owner=owner) }} <br />
                    {% endif %}
                    {{ _('The base template for this dashboard was created by <a href="https://appseed.us/app-generator">AppSeed Web App Generator</a>, protected under <a href="https://github.com/app-generator/flask-black-dashboard/blob/master/LICENSE.md">MIT License</a>.')|safe
                    }}
                    <br />
                    {{ _('The dashboard was edited and recoded to work with Red Discord Bot by <a href="https://github.com/NeuroAssassin">Neuro Assassin#4779</a>, protected under <a href="https://github.com/Cog-Creators/Red-Dashboard/blob/master/LICENSE">Affero General Public License v3.0</a>.')|safe
                    }}<br />
                    {{ _('This dashboard was made for <a href="https://github.com/Cog-Creators/Red-DiscordBot">Red Discord Bot</a>, a multifunctional, fully modular Discord bot, created by Twentysix, made great by many.  Red Discord Bot is protected under <a href="https://github.com/Cog-Creators/Red-DiscordBot/blob/V3/develop/LICENSE">GNU General Public License v3.0</a>.')|safe
                    }}
                </h4>
            </div>
            <div class="card-body">
                <h6 class="card-category text-gray">Policies and Disclaimers</h6>
                <ul>
                    <li>{{ _('Privacy Policy:') }} <a
                            href="https://github.com/Cog-Creators/Red-Dashboard/blob/master/documents/Privacy%20Policy.md">https://github.com/Cog-Creators/Red-Dashboard/blob/master/documents/Privacy%20Policy.md</a>
                    </li>
                    <li>{{ _('Cookie Policy:') }} <a
                            href="https://github.com/Cog-Creators/Red-Dashboard/blob/master/documents/Cookie%20Policy.md">https://github.com/Cog-Creators/Red-Dashboard/blob/master/documents/Cookie%20Policy.md</a>
                    </li>
                    <li>{{ _('Third Party Disclaimer:') }} <a
                            href="https://github.com/Cog-Creators/Red-Dashboard/blob/master/documents/Third%20Party%20Disclaimer.md">https://github.com/Cog-Creators/Red-Dashboard/blob/master/documents/Third%20Party%20Disclaimer.md</a>
                    </li>
                </ul>
            </div>
            <div class="card-footer">
                {{ _('Dashboard Version {version}').format(version=version) }}
            </div>
        </div>
    </div>
</div>

{% endblock content %}

<!-- Specific Page JS goes HERE  -->
{% block javascripts %}{% endblock javascripts %}