<footer class="footer">
  <div class="container-fluid">
    <ul class="nav">
      <li class="nav-item">
        <a href="https://appseed.us/admin-dashboards/flask-dashboard-black" class="nav-link">
          Flask Dashboard Black
        </a>
      </li>
      <li class="nav-item">
        <a href="https://github.com/NeuroAssassin" class="nav-link">
          {{ _('Adapted for Red Discord Bot') }}
        </a>
      </li>
    </ul>
    <div class="copyright">
      &copy; <a href="https://www.creative-tim.com/">Creative-Tim</a> - {{ _('Coded in Flask by AppSeed') }}
    </div>
  </div>
</footer>