{% extends "base-site.html" %}

{% block title %} {{ _('Page 500') }} {% endblock %}

<!-- Specific Page CSS goes HERE  -->
{% block stylesheets %}{% endblock stylesheets %}

{% block content %}

<div class="row">
    <div class="col-md-12">
        <div class="card card-profile">
            <div class="card-body">
                <h6 class="card-category text-gray">{{ _('Uh oh!') }}</h6>
                <h4 class="card-title">
                    {{ _('Error 500') }}
                </h4>
                <p>{{ _("Looks like the server ran into an issue... Strange...") }}</p>
                <a href="{{ url_for('base_blueprint.index') }}"><button class="btn">{{ _('Home') }}</button></a>
            </div>
        </div>
    </div>
</div>


{% endblock content %}

<!-- Specific Page JS goes HERE  -->
{% block javascripts %}{% endblock javascripts %}